# hyprbop
A hacky utility for creating custom popups on hyprland

# Usage
```bash
hyprbop <configname>
```

# Config
- Config directory: ~/.config/hyprbop/
- Config files: <configname>.json, style.qss
- See example config [power.json](src/hyprbop/config/power.json)

# Showcase
<video src="https://github.com/user-attachments/assets/7b08b45a-dd1d-446b-96b5-2a028c98ac0e
" controls preload></video>
